@@ -1,5 +1,6 @@
 __version__ = '1.0.6'
 
+# next base
 from jsw_nx.base.set import set
 from jsw_nx.base.forin import forin
 from jsw_nx.base.get import get
@@ -10,4 +11,13 @@ from jsw_nx.base.find_index import find_index
 from jsw_nx.base.map import map
 from jsw_nx.base.reduce import reduce
 from jsw_nx.base.filter import filter
+from jsw_nx.base.mix import mix
+
+# ruby style
+from jsw_nx.rubify.to_i import to_i
+from jsw_nx.rubify.to_f import to_f
+from jsw_nx.rubify.to_s import to_s
+from jsw_nx.rubify.to_n import to_n
+
+# next packages
 from jsw_nx.packages.days import days
